@@ -143,35 +143,6 @@ ephy_download_get_content_type (EphyDownload *download)
   return download->content_type;
 }
 
-/* Helper function to decide what EphyDownloadActionType should be the
- * default for the download. This implies that you want something to
- * happen, this function will never return EPHY_DOWNLOAD_ACTION_NONE.
- */
-static EphyDownloadActionType
-decide_action_from_mime (EphyDownload *ephy_download)
-{
-  const char *content_type;
-  GAppInfo *helper_app = NULL;
-  EphyDownloadActionType action;
-
-  content_type = ephy_download_get_content_type (ephy_download);
-  if (content_type) {
-    helper_app = g_app_info_get_default_for_type (content_type, FALSE);
-    if (helper_app)
-      action = EPHY_DOWNLOAD_ACTION_OPEN;
-  }
-
-  /* Downloads that have no content_type, or no helper_app, are
-   * considered unsafe/unable to open. Default them to BROWSE_TO.
-   */
-  if (helper_app == NULL)
-    action = EPHY_DOWNLOAD_ACTION_BROWSE_TO;
-  else
-    g_object_unref (helper_app);
-
-  return action;
-}
-
 /* From the old embed/mozilla/MozDownload.cpp */
 static const char *
 file_is_compressed (const char *filename)
@@ -440,21 +411,10 @@ ephy_download_failed (EphyDownload *download,
   return FALSE;
 }
 
-/**
- * ephy_download_do_download_action:
- * @download: an #EphyDownload
- * @action: one of #EphyDownloadActionType
- *
- * Executes the given @action for @download, this can be any of
- * #EphyDownloadActionType, including #EPHY_DOWNLOAD_ACTION_AUTO which decides
- * the default action from the mime type of @download.
- *
- * Returns: %TRUE if the action was executed succesfully.
- *
- **/
-gboolean
-ephy_download_do_download_action (EphyDownload          *download,
-                                  EphyDownloadActionType action)
+static gboolean
+ephy_download_do_download_action_internal (EphyDownload *download,
+                                           EphyDownloadActionType action,
+                                           guint32 user_time)
 {
   GFile *destination;
   const char *destination_uri;
@@ -464,39 +424,47 @@ ephy_download_do_download_action (EphyDownload          *download,
   destination = g_file_new_for_uri (destination_uri);
 
   switch ((action ? action : download->action)) {
-    case EPHY_DOWNLOAD_ACTION_AUTO:
-      LOG ("ephy_download_do_download_action: auto");
-      ret = ephy_download_do_download_action (download, decide_action_from_mime (download));
-      break;
-    case EPHY_DOWNLOAD_ACTION_BROWSE_TO:
-      LOG ("ephy_download_do_download_action: browse_to");
-      ret = ephy_file_browse_to (destination, download->start_time);
-      break;
     case EPHY_DOWNLOAD_ACTION_OPEN:
       LOG ("ephy_download_do_download_action: open");
       ret = ephy_embed_shell_launch_handler (ephy_embed_shell_get_default (),
-                                             destination, NULL, download->start_time);
-      if (!ret)
-        ret = ephy_file_browse_to (destination, download->start_time);
+                                             destination, NULL, user_time);
+      /* Fall through if we did not open anything. */
+      if (ret)
+        break;
+    case EPHY_DOWNLOAD_ACTION_BROWSE_TO:
+      LOG ("ephy_download_do_download_action: browse_to");
+      ret = ephy_file_browse_to (destination, user_time);
       break;
     case EPHY_DOWNLOAD_ACTION_NONE:
       LOG ("ephy_download_do_download_action: none");
       ret = TRUE;
       break;
-    case EPHY_DOWNLOAD_ACTION_DO_NOTHING:
-      LOG ("ephy_download_do_download_action: nothing");
-      ret = TRUE;
-      break;
     default:
-      LOG ("ephy_download_do_download_action: unhandled action");
-      ret = FALSE;
-      break;
+      g_assert_not_reached ();
   }
   g_object_unref (destination);
 
   return ret;
 }
 
+/**
+ * ephy_download_do_download_action:
+ * @download: an #EphyDownload
+ * @action: one of #EphyDownloadActionType
+ *
+ * Executes the given @action for @download, this can be any of
+ * #EphyDownloadActionType.
+ *
+ * Returns: %TRUE if the action was executed succesfully.
+ *
+ **/
+gboolean
+ephy_download_do_download_action (EphyDownload          *download,
+                                  EphyDownloadActionType action)
+{
+  return ephy_download_do_download_action_internal (download, action, g_get_real_time ());
+}
+
 static void
 ephy_download_dispose (GObject *object)
 {
@@ -731,9 +699,9 @@ download_finished_cb (WebKitDownload *wk_download,
 
   if (g_settings_get_boolean (EPHY_SETTINGS_MAIN, EPHY_PREFS_AUTO_DOWNLOADS) &&
       download->action == EPHY_DOWNLOAD_ACTION_NONE)
-    ephy_download_do_download_action (download, EPHY_DOWNLOAD_ACTION_AUTO);
+    ephy_download_do_download_action_internal (download, EPHY_DOWNLOAD_ACTION_OPEN, download->start_time);
   else
-    ephy_download_do_download_action (download, download->action);
+    ephy_download_do_download_action_internal (download, download->action, download->start_time);
 }
 
 static void
