@@ -16,10 +16,6 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
-#error "Only <epiphany/epiphany.h> can be included directly."
-#endif
-
 #ifndef EPHY_URI_HELPERS_H
 #define EPHY_URI_HELPERS_H
 
@@ -28,7 +24,8 @@
 G_BEGIN_DECLS
 
 char *ephy_remove_tracking_from_uri (const char *uri);
-char *ephy_uri_safe_unescape (const char *uri);
+char *ephy_uri_decode (const char *uri);
+char *ephy_uri_normalize (const char *uri);
 
 G_END_DECLS
 
