@@ -315,9 +315,12 @@ ephy_title_box_button_press_event (GtkWidget      *widget,
   EphyTitleBox        *title_box = EPHY_TITLE_BOX (widget);
   GtkAllocation lock_allocation;
 
-  if (title_box->mode != EPHY_TITLE_BOX_MODE_TITLE || event->button != GDK_BUTTON_PRIMARY)
+  if (title_box->mode != EPHY_TITLE_BOX_MODE_TITLE)
     return GDK_EVENT_PROPAGATE;
 
+  if (event->button != GDK_BUTTON_PRIMARY)
+    return GDK_EVENT_STOP;
+
   LOG ("button-press-event title-box %p event %p", title_box, event);
 
   gtk_widget_get_allocation (title_box->lock_image, &lock_allocation);
@@ -334,7 +337,7 @@ ephy_title_box_button_press_event (GtkWidget      *widget,
     ephy_title_box_cancel_switch_to_entry_after_double_click_time (title_box);
   }
 
-  return GDK_EVENT_PROPAGATE;
+  return GDK_EVENT_STOP;
 }
 
 static void
